@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2018-2025 Mike Fährmann
+# Copyright 2018-2026 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -64,7 +64,7 @@ class ArtstationExtractor(Extractor):
                     if "/images/images/" in url:
                         lhs, _, rhs = url.partition("/large/")
                         if rhs:
-                            url = f"{lhs}/4k/{rhs}"
+                            url = f"{lhs}/8k/{rhs}"
                             asset["_fallback"] = self._image_fallback(lhs, rhs)
 
                     yield Message.Url, url, asset
@@ -88,7 +88,8 @@ class ArtstationExtractor(Extractor):
                 if not self.videos:
                     return
                 page = self.request(url).text
-                return text.extr(page, ' src="', '"')
+                return text.extract(
+                    page, ' src="', '"', page.find('id="video"')+1)[0]
 
         if url:
             # external URL
@@ -102,6 +103,7 @@ class ArtstationExtractor(Extractor):
                          adict.get("id"))
 
     def _image_fallback(self, lhs, rhs):
+        yield f"{lhs}/4k/{rhs}"
         yield f"{lhs}/large/{rhs}"
         yield f"{lhs}/medium/{rhs}"
         yield f"{lhs}/small/{rhs}"
@@ -317,9 +319,9 @@ class ArtstationChallengeExtractor(ArtstationExtractor):
                      "{challenge[id]} - {challenge[title]}")
     archive_fmt = "c_{challenge[id]}_{asset_id}"
     pattern = (r"(?:https?://)?(?:www\.)?artstation\.com"
-               r"/contests/[^/?#]+/challenges/(\d+)"
+               r"/c(?:hallenges|ontests)/[^/?#]+/c(?:ategori|halleng)es/(\d+)"
                r"/?(?:\?sorting=([a-z]+))?")
-    example = "https://www.artstation.com/contests/NAME/challenges/12345"
+    example = "https://www.artstation.com/challenges/NAME/categories/12345"
 
     def __init__(self, match):
         ArtstationExtractor.__init__(self, match)
@@ -327,24 +329,28 @@ class ArtstationChallengeExtractor(ArtstationExtractor):
         self.sorting = match[2] or "popular"
 
     def items(self):
-        base = f"{self.root}/contests/_/challenges/{self.challenge_id}"
-        challenge_url = base + ".json"
-        submission_url = base + "/submissions.json"
-        update_url = self.root + "/contests/submission_updates.json"
+        base = self.root + "/api/v2/competition/"
+        challenge_url = f"{base}challenges/{self.challenge_id}.json"
+        submission_url = base + "submissions.json"
 
         challenge = self.request_json(challenge_url)
         yield Message.Directory, "", {"challenge": challenge}
 
-        params = {"sorting": self.sorting}
+        params = {
+            "page"        : 1,
+            "per_page"    : 50,
+            "challenge_id": self.challenge_id,
+            "sort_by"     : self.sorting,
+        }
+
         for submission in self._pagination(submission_url, params):
-
-            params = {"submission_id": submission["id"]}
+            update_url = (f"{base}submissions/{submission['id']}"
+                          f"/submission_updates.json")
+            params = {"page": 1, "per_page": 50}
             for update in self._pagination(update_url, params=params):
-
-                del update["replies"]
                 update["challenge"] = challenge
-                for url in text.extract_iter(
-                        update["body_presentation_html"], ' href="', '"'):
+                for url in util.unique_sequence(text.extract_iter(
+                        update["body"], ' href="', '"')):
                     update["asset_id"] = self._id_from_url(url)
                     text.nameext_from_url(url, update)
                     yield Message.Url, self._no_cache(url), update
