@@ -20,7 +20,7 @@ class E621Extractor(danbooru.DanbooruExtractor):
     page_limit = 750
     page_start = None
     per_page = 320
-    useragent = util.USERAGENT + " (by mikf)"
+    useragent = util.USERAGENT_GALLERYDL + " (by mikf)"
     request_interval_min = 1.0
 
     def items(self):
@@ -94,13 +94,13 @@ BASE_PATTERN = E621Extractor.update({
 
 class E621TagExtractor(E621Extractor, danbooru.DanbooruTagExtractor):
     """Extractor for e621 posts from tag searches"""
-    pattern = rf"{BASE_PATTERN}/posts?(?:\?[^#]*?tags=|/index/\d+/)([^&#]*)"
+    pattern = BASE_PATTERN + r"/posts?(?:\?[^#]*?tags=|/index/\d+/)([^&#]*)"
     example = "https://e621.net/posts?tags=TAG"
 
 
 class E621PoolExtractor(E621Extractor, danbooru.DanbooruPoolExtractor):
     """Extractor for e621 pools"""
-    pattern = rf"{BASE_PATTERN}/pool(?:s|/show)/(\d+)"
+    pattern = BASE_PATTERN + r"/pool(?:s|/show)/(\d+)"
     example = "https://e621.net/pools/12345"
 
     def posts(self):
@@ -125,7 +125,7 @@ class E621PoolExtractor(E621Extractor, danbooru.DanbooruPoolExtractor):
 
 class E621PostExtractor(E621Extractor, danbooru.DanbooruPostExtractor):
     """Extractor for single e621 posts"""
-    pattern = rf"{BASE_PATTERN}/post(?:s|/show)/(\d+)"
+    pattern = BASE_PATTERN + r"/post(?:s|/show)/(\d+)"
     example = "https://e621.net/posts/12345"
 
     def posts(self):
@@ -135,7 +135,7 @@ class E621PostExtractor(E621Extractor, danbooru.DanbooruPostExtractor):
 
 class E621PopularExtractor(E621Extractor, danbooru.DanbooruPopularExtractor):
     """Extractor for popular images from e621"""
-    pattern = rf"{BASE_PATTERN}/explore/posts/popular(?:\?([^#]*))?"
+    pattern = BASE_PATTERN + r"/explore/posts/popular(?:\?([^#]*))?"
     example = "https://e621.net/explore/posts/popular"
 
     def posts(self):
@@ -145,7 +145,7 @@ class E621PopularExtractor(E621Extractor, danbooru.DanbooruPopularExtractor):
 class E621ArtistExtractor(E621Extractor, danbooru.DanbooruArtistExtractor):
     """Extractor for e621 artists"""
     subcategory = "artist"
-    pattern = rf"{BASE_PATTERN}/artists/(\d+)"
+    pattern = BASE_PATTERN + r"/artists/(\d+)"
     example = "https://e621.net/artists/12345"
 
     items = E621Extractor.items_artists
@@ -155,7 +155,7 @@ class E621ArtistSearchExtractor(E621Extractor,
                                 danbooru.DanbooruArtistSearchExtractor):
     """Extractor for e621 artist searches"""
     subcategory = "artist-search"
-    pattern = rf"{BASE_PATTERN}/artists/?\?([^#]+)"
+    pattern = BASE_PATTERN + r"/artists/?\?([^#]+)"
     example = "https://e621.net/artists?QUERY"
 
     items = E621Extractor.items_artists
@@ -166,7 +166,7 @@ class E621FavoriteExtractor(E621Extractor):
     subcategory = "favorite"
     directory_fmt = ("{category}", "Favorites", "{user_id}")
     archive_fmt = "f_{user_id}_{id}"
-    pattern = rf"{BASE_PATTERN}/favorites(?:\?([^#]*))?"
+    pattern = BASE_PATTERN + r"/favorites(?:\?([^#]*))?"
     example = "https://e621.net/favorites"
 
     def metadata(self):
