@@ -25,19 +25,20 @@ class FanslyExtractor(Extractor):
 
     def _init(self):
         self.api = FanslyAPI(self)
+        self.previews = self.config("previews", True)
 
         if fmts := self.config("formats"):
             self.formats = set(fmts)
         else:
-            self.formats = {1, 2, 3, 4, 302, 303}
+            self.formats = None
 
     def items(self):
         for post in self.posts():
             files = self._extract_files(post)
             post["count"] = len(files)
-            post["date"] = text.parse_timestamp(post["createdAt"])
+            post["date"] = self.parse_timestamp(post["createdAt"])
 
-            yield Message.Directory, post
+            yield Message.Directory, "", post
             for post["num"], file in enumerate(files, 1):
                 post.update(file)
                 url = file["url"]
@@ -61,7 +62,8 @@ class FanslyExtractor(Extractor):
             yield from self.posts_wall(account, wall)
 
     def _extract_files(self, post):
-        files = []
+        if "attachments" not in post:
+            return ()
 
         if "_extra" in post:
             extra = post.pop("_extra", ())
@@ -75,34 +77,41 @@ class FanslyExtractor(Extractor):
                 if mid in media
             )
 
+        files = []
         for attachment in post.pop("attachments"):
             try:
                 self._extract_attachment(files, post, attachment)
             except Exception as exc:
-                self.log.debug("", exc_info=exc)
+                self.log.traceback(exc)
                 self.log.error(
                     "%s/%s, Failed to extract media (%s: %s)",
                     post["id"], attachment.get("id"),
                     exc.__class__.__name__, exc)
         return files
 
-    def _extract_attachment(self, files, post, attachment):
-        media = attachment["media"]
+    def _extract_attachment(self, files, post, attachment, preview=False):
+        media = attachment["preview" if preview else "media"]
 
         variants = media.pop("variants") or []
         if media.get("locations"):
             variants.append(media)
 
+        fmts = self.formats
         formats = [
             (variant["width"], (type-500 if type > 256 else type), variant)
             for variant in variants
             if variant.get("locations") and
-            (type := variant["type"]) in self.formats
+            (type := variant["type"]) and
+            (fmts is None or type in fmts)
         ]
 
         try:
             variant = max(formats)[-1]
         except Exception:
+            if self.previews and "preview" in attachment and not preview:
+                self.log.info("%s/%s: Downloading Preview",
+                              post["id"], attachment["id"])
+                return self._extract_attachment(files, post, attachment, True)
             return self.log.warning("%s/%s: No format available",
                                     post["id"], attachment["id"])
 
@@ -116,9 +125,10 @@ class FanslyExtractor(Extractor):
 
         file = {
             **variant,
+            "preview": preview,
             "format": variant["type"],
-            "date": text.parse_timestamp(media["createdAt"]),
-            "date_updated": text.parse_timestamp(media["updatedAt"]),
+            "date": self.parse_timestamp(media["createdAt"]),
+            "date_updated": self.parse_timestamp(media["updatedAt"]),
         }
 
         if "metadata" in location:
@@ -133,7 +143,7 @@ class FanslyExtractor(Extractor):
 
             files.append({
                 "file": file,
-                "url": f"ytdl:{location['location']}",
+                "url": "ytdl:" + location["location"],
                 "_fallback": fallback,
                 "_ytdl_manifest":
                     "dash" if mime == "application/dash+xml" else "hls",
@@ -153,7 +163,7 @@ class FanslyExtractor(Extractor):
 
 class FanslyPostExtractor(FanslyExtractor):
     subcategory = "post"
-    pattern = rf"{BASE_PATTERN}/post/(\d+)"
+    pattern = BASE_PATTERN + r"/post/(\d+)"
     example = "https://fansly.com/post/1234567890"
 
     def posts(self):
@@ -162,7 +172,7 @@ class FanslyPostExtractor(FanslyExtractor):
 
 class FanslyHomeExtractor(FanslyExtractor):
     subcategory = "home"
-    pattern = rf"{BASE_PATTERN}/home(?:/(?:subscribed()|list/(\d+)))?"
+    pattern = BASE_PATTERN + r"/home(?:/(?:subscribed()|list/(\d+)))?"
     example = "https://fansly.com/home"
 
     def posts(self):
@@ -178,11 +188,11 @@ class FanslyHomeExtractor(FanslyExtractor):
 
 class FanslyListExtractor(FanslyExtractor):
     subcategory = "list"
-    pattern = rf"{BASE_PATTERN}/lists/(\d+)"
+    pattern = BASE_PATTERN + r"/lists/(\d+)"
     example = "https://fansly.com/lists/1234567890"
 
     def items(self):
-        base = f"{self.root}/"
+        base = self.root + "/"
         for account in self.api.lists_itemsnew(self.groups[0]):
             account["_extractor"] = FanslyCreatorPostsExtractor
             url = f"{base}{account['username']}/posts"
@@ -191,11 +201,11 @@ class FanslyListExtractor(FanslyExtractor):
 
 class FanslyListsExtractor(FanslyExtractor):
     subcategory = "lists"
-    pattern = rf"{BASE_PATTERN}/lists"
+    pattern = BASE_PATTERN + r"/lists"
     example = "https://fansly.com/lists"
 
     def items(self):
-        base = f"{self.root}/lists/"
+        base = self.root + "/lists/"
         for list in self.api.lists_account():
             list["_extractor"] = FanslyListExtractor
             url = f"{base}{list['id']}#{list['label']}"
@@ -204,7 +214,7 @@ class FanslyListsExtractor(FanslyExtractor):
 
 class FanslyCreatorPostsExtractor(FanslyExtractor):
     subcategory = "creator-posts"
-    pattern = rf"{BASE_PATTERN}/([^/?#]+)/posts(?:/wall/(\d+))?"
+    pattern = BASE_PATTERN + r"/([^/?#]+)/posts(?:/wall/(\d+))?"
     example = "https://fansly.com/CREATOR/posts"
 
     def posts_wall(self, account, wall):
@@ -213,7 +223,7 @@ class FanslyCreatorPostsExtractor(FanslyExtractor):
 
 class FanslyCreatorMediaExtractor(FanslyExtractor):
     subcategory = "creator-media"
-    pattern = rf"{BASE_PATTERN}/([^/?#]+)/media(?:/wall/(\d+))?"
+    pattern = BASE_PATTERN + r"/([^/?#]+)/media(?:/wall/(\d+))?"
     example = "https://fansly.com/CREATOR/media"
 
     def posts_wall(self, account, wall):
@@ -306,7 +316,7 @@ class FanslyAPI():
         return self._pagination(endpoint, params)
 
     def timeline_new(self, account_id, wall_id):
-        endpoint = f"/v1/timelinenew/{account_id}"
+        endpoint = "/v1/timelinenew/" + str(account_id)
         params = {
             "before"       : "0",
             "after"        : "0",
@@ -331,12 +341,20 @@ class FanslyAPI():
 
         posts = response["posts"]
         for post in posts:
-            post["account"] = accounts[post.pop("accountId")]
+            try:
+                post["account"] = accounts[post.pop("accountId")]
+            except KeyError:
+                pass
 
             extra = None
             attachments = []
             for attachment in post["attachments"]:
-                cid = attachment["contentId"]
+                try:
+                    cid = attachment["contentId"]
+                except KeyError:
+                    attachments.append(attachment)
+                    continue
+
                 if cid in media:
                     attachments.append(media[cid])
                 elif cid in bundles:
