@@ -9,8 +9,8 @@
 
 """Extractors for https://www.mangakakalot.gg/ and mirror sites"""
 
-from .common import BaseExtractor, ChapterExtractor, MangaExtractor
-from .. import text, util
+from .common import BaseExtractor, ChapterExtractor, MangaExtractor, Message
+from .. import text, util, exception
 
 
 class ManganeloExtractor(BaseExtractor):
@@ -44,16 +44,16 @@ class ManganeloChapterExtractor(ManganeloExtractor, ChapterExtractor):
 
     def __init__(self, match):
         ManganeloExtractor.__init__(self, match)
-        self.gallery_url = self.root + self.groups[-1]
+        self.page_url = self.root + self.groups[-1]
 
     def metadata(self, page):
         extr = text.extract_from(page)
 
         data = {
-            "date"        : text.parse_datetime(extr(
-                '"datePublished": "', '"')[:19], "%Y-%m-%dT%H:%M:%S"),
-            "date_updated": text.parse_datetime(extr(
-                '"dateModified": "', '"')[:19], "%Y-%m-%dT%H:%M:%S"),
+            "date"        : self.parse_datetime_iso(extr(
+                '"datePublished": "', '"')[:19]),
+            "date_updated": self.parse_datetime_iso(extr(
+                '"dateModified": "', '"')[:19]),
             "manga_id"    : text.parse_int(extr("comic_id =", ";")),
             "chapter_id"  : text.parse_int(extr("chapter_id =", ";")),
             "manga"       : extr("comic_name =", ";").strip('" '),
@@ -91,7 +91,7 @@ class ManganeloMangaExtractor(ManganeloExtractor, MangaExtractor):
 
     def __init__(self, match):
         ManganeloExtractor.__init__(self, match)
-        self.manga_url = self.root + self.groups[-1]
+        self.page_url = self.root + self.groups[-1]
 
     def chapters(self, page):
         extr = text.extract_from(page)
@@ -99,7 +99,7 @@ class ManganeloMangaExtractor(ManganeloExtractor, MangaExtractor):
         manga = text.unescape(extr("<h1>", "<"))
         author = text.remove_html(extr("<li>Author(s) :", "</a>"))
         status = extr("<li>Status :", "<").strip()
-        update = text.parse_datetime(extr(
+        update = self.parse_datetime(extr(
             "<li>Last updated :", "<").strip(), "%b-%d-%Y %I:%M:%S %p")
         tags = text.split_html(extr(">Genres :", "</li>"))[::2]
 
@@ -121,8 +121,38 @@ class ManganeloMangaExtractor(ManganeloExtractor, MangaExtractor):
                 "chapter" : text.parse_int(chapter),
                 "chapter_minor": (sep and ".") + minor,
                 "title"   : title.partition(": ")[2],
-                "date"    : text.parse_datetime(date, "%b-%d-%Y %H:%M"),
+                "date"    : self.parse_datetime(date, "%b-%d-%Y %H:%M"),
                 "lang"    : "en",
                 "language": "English",
             }))
         return results
+
+
+class ManganeloBookmarkExtractor(ManganeloExtractor):
+    """Extractor for manganelo bookmarks"""
+    subcategory = "bookmark"
+    pattern = BASE_PATTERN + r"/bookmark"
+    example = "https://www.mangakakalot.gg/bookmark"
+
+    def items(self):
+        data = {"_extractor": ManganeloMangaExtractor}
+
+        url = self.root + "/bookmark"
+        params = {"page": 1}
+
+        response = self.request(url, params=params)
+        if response.history:
+            raise exception.AuthRequired(
+                "authenticated cookies", "your bookmarks")
+        page = response.text
+        last = text.parse_int(text.extr(page, ">Last(", ")"))
+
+        while True:
+            for bookmark in text.extract_iter(
+                    page, 'class="user-bookmark-item ', '</a>'):
+                yield Message.Queue, text.extr(bookmark, ' href="', '"'), data
+
+            if params["page"] >= last:
+                break
+            params["page"] += 1
+            page = self.request(url, params=params).text
