@@ -214,6 +214,7 @@ Request interval (default):
     def test_base_category(self):
         extr = TestExtractor.from_url("test:")
         extr.basecategory = "test_basecategory"
+        extr.basesubcategory = "test_basesubcategory"
 
         self.assertEqual(self._capture_stdout(extr), """\
 Category / Subcategory / Basecategory
@@ -299,7 +300,7 @@ class TestDataJob(TestJob):
         for i in range(1, 4):
             self.assertEqual(
                 tjob.data[i][2]["_fallback"],
-                ("https://example.org/alt/{}.jpg".format(i),),
+                (f"https://example.org/alt/{i}.jpg",),
             )
 
     def test_sleep(self):
@@ -358,6 +359,25 @@ class TestDataJob(TestJob):
         self.assertEqual(tjob.data[-1][0], Message.Url)
         self.assertEqual(tjob.data[-1][2]["num"], "3")
 
+    def test_jsonl(self):
+        extr = TestExtractor.from_url("test:")
+        tjob = self.jobclass(extr, file=io.StringIO())
+        with patch("gallery_dl.job.DataJob.out") as out:
+            tjob.run()
+        self.assertEqual(len(out.call_args_list), 0)
+
+        config.set(("output",), "jsonl", True)
+        extr = TestExtractor.from_url("test:")
+        file = io.StringIO()
+        tjob = self.jobclass(extr, file=file)
+        with patch("gallery_dl.job.DataJob.out") as out:
+            tjob.run()
+        self.assertEqual(len(out.call_args_list), 4)
+
+        tjob.run()
+        for line in file.getvalue().split():
+            self.assertRegex(line, r"""^\[[23],("http[^"]+",)?\{.+\}\]$""")
+
 
 class TestExtractor(Extractor):
     category = "test_category"
@@ -376,19 +396,19 @@ class TestExtractor(Extractor):
         root = "https://example.org"
         user = self.user
 
-        yield Message.Directory, {
+        yield Message.Directory, "", {
             "user": user,
             "author": user,
         }
 
         for i in range(1, 4):
-            url = "{}/{}.jpg".format(root, i)
+            url = f"{root}/{i}.jpg"
             yield Message.Url, url, text.nameext_from_url(url, {
                 "num" : i,
                 "tags": ["foo", "bar", "テスト"],
                 "user": user,
                 "author": user,
-                "_fallback": ("{}/alt/{}.jpg".format(root, i),),
+                "_fallback": (f"{root}/alt/{i}.jpg",),
             })
 
 
